==> xmonad-dbus-0.1.0.2-230.1-loong64.pkg.tar.zst: usr/share/haskell/register/xmonad-dbus.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-dbus
version:              0.1.0.2
visibility:           public
id:                   xmonad-dbus-0.1.0.2-AW6I0AGlQnE7eAgs47nXOC
key:                  xmonad-dbus-0.1.0.2-AW6I0AGlQnE7eAgs47nXOC
license:              BSD-3-Clause
copyright:            2018-2023 Dmitry Geurkov
maintainer:           d.geurkov@gmail.com
author:               Dmitry Geurkov
homepage:             https://github.com/troydm/xmonad-dbus#readme
description:
    Please see the README on Github at <https://github.com/githubuser/xmonad-dbus#readme>

abi:                  4075205439694369f1182d248a76a9b1
exposed:              True
exposed-modules:      XMonad.DBus
hidden-modules:       Paths_xmonad_dbus
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-dbus
hs-libraries:         HSxmonad-dbus-0.1.0.2-AW6I0AGlQnE7eAgs47nXOC
depends:              base-4.18.2.1 dbus-1.3.3-11fa9uMK72Y1CHWrLdB8AG
haddock-interfaces:   /usr/share/doc/xmonad-dbus/html/xmonad-dbus.haddock
haddock-html:         /usr/share/doc/xmonad-dbus/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-dbus-0.1.0.2-232-loong64.pkg.tar.zst: usr/share/haskell/register/xmonad-dbus.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-dbus
version:              0.1.0.2
visibility:           public
id:                   xmonad-dbus-0.1.0.2-4kyuqyRms1WHfc6AGBjJHm
key:                  xmonad-dbus-0.1.0.2-4kyuqyRms1WHfc6AGBjJHm
license:              BSD-3-Clause
copyright:            2018-2023 Dmitry Geurkov
maintainer:           d.geurkov@gmail.com
author:               Dmitry Geurkov
homepage:             https://github.com/troydm/xmonad-dbus#readme
description:
    Please see the README on Github at <https://github.com/githubuser/xmonad-dbus#readme>

abi:                  69b74f22aa3de0d217daafaacadb5d7e
exposed:              True
exposed-modules:      XMonad.DBus
hidden-modules:       Paths_xmonad_dbus
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xmonad-dbus-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-dbus
hs-libraries:         HSxmonad-dbus-0.1.0.2-4kyuqyRms1WHfc6AGBjJHm
depends:              base-4.18.2.1 dbus-1.3.3-INvnWTkkmrECqNpDSboXTA
haddock-interfaces:   /usr/share/doc/xmonad-dbus/html/xmonad-dbus.haddock
haddock-html:         /usr/share/doc/xmonad-dbus/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
